@@ -1,21 +1,24 @@
+from typing import Union, Optional
+
 import tensorflow as tf
 
 from . import dispatch, B, Numeric
 from .custom import tensorflow_register
 from ..custom import toeplitz_solve, s_toeplitz_solve, expm, s_expm, logm, s_logm
 from ..linear_algebra import _default_perm
+from ..types import Int
 from ..util import resolve_axis
 
 __all__ = []
 
 
 @dispatch
-def matmul(a: Numeric, b: Numeric, tr_a=False, tr_b=False):
+def matmul(a: Numeric, b: Numeric, tr_a: bool = False, tr_b: bool = False):
     return tf.matmul(a, b, transpose_a=tr_a, transpose_b=tr_b)
 
 
 @dispatch
-def transpose(a: Numeric, perm=None):
+def transpose(a: Numeric, perm: Optional[Union[tuple, list]] = None):
     # Correctly handle special cases.
     rank_a = B.rank(a)
     if rank_a == 0:
@@ -29,7 +32,7 @@ def transpose(a: Numeric, perm=None):
 
 
 @dispatch
-def trace(a: Numeric, axis1=-2, axis2=-1):
+def trace(a: Numeric, axis1: Int = -2, axis2: Int = -1):
     axis1 = resolve_axis(a, axis1)
     axis2 = resolve_axis(a, axis2)
     perm = [i for i in range(B.rank(a)) if i not in [axis1, axis2]]
@@ -54,7 +57,7 @@ def kron(a: Numeric, b: Numeric):
 
 
 @dispatch
-def svd(a: Numeric, compute_uv=True):
+def svd(a: Numeric, compute_uv: bool = True):
     res = tf.linalg.svd(a, full_matrices=False, compute_uv=compute_uv)
     return (res[1], res[0], res[2]) if compute_uv else res
 
@@ -106,7 +109,7 @@ def cholesky_solve(a: Numeric, b: Numeric):
 
 
 @dispatch
-def triangular_solve(a: Numeric, b: Numeric, lower_a=True):
+def triangular_solve(a: Numeric, b: Numeric, lower_a: bool = True):
     return tf.linalg.triangular_solve(a, b, lower=lower_a)
 
 
