@@ -260,7 +260,9 @@ def test_take_tf(check_lazy_shapes):
     a = Matrix(3, 4, 5)
     ref = Tensor(3)
     approx(B.take(a.tf(), ref.tf() > 0), B.take(a.np(), ref.np() > 0))
+    approx(B.take(a.tf(), ref.np() > 0), B.take(a.np(), ref.np() > 0))
     approx(B.take(a.tf(), B.range(tf.int64, 2)), B.take(a.np(), B.range(2)))
+    approx(B.take(a.tf(), B.range(np.int64, 2)), B.take(a.np(), B.range(2)))
 
 
 def test_submatrix(check_lazy_shapes):
